You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cloudstack.apache.org by de...@apache.org on 2014/03/27 11:50:02 UTC

git commit: updated refs/heads/master to e3e4526

Repository: cloudstack
Updated Branches:
  refs/heads/master c46088c96 -> e3e452625


CLOUDSTACK-6267: unblocking smb as zone wide primary storage for hyperv

Signed-off-by: Devdeep Singh <de...@gmail.com>


Project: http://git-wip-us.apache.org/repos/asf/cloudstack/repo
Commit: http://git-wip-us.apache.org/repos/asf/cloudstack/commit/e3e45262
Tree: http://git-wip-us.apache.org/repos/asf/cloudstack/tree/e3e45262
Diff: http://git-wip-us.apache.org/repos/asf/cloudstack/diff/e3e45262

Branch: refs/heads/master
Commit: e3e452625efdeca7578b1cd80a3faf57ea087220
Parents: c46088c
Author: Anshul Gangwar <an...@citrix.com>
Authored: Fri Mar 21 12:05:23 2014 +0530
Committer: Devdeep Singh <de...@gmail.com>
Committed: Thu Mar 27 16:24:40 2014 +0530

----------------------------------------------------------------------
 server/src/com/cloud/storage/StorageManagerImpl.java | 2 +-
 ui/scripts/system.js                                 | 6 +++++-
 ui/scripts/zoneWizard.js                             | 4 ++--
 3 files changed, 8 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cloudstack/blob/e3e45262/server/src/com/cloud/storage/StorageManagerImpl.java
----------------------------------------------------------------------
diff --git a/server/src/com/cloud/storage/StorageManagerImpl.java b/server/src/com/cloud/storage/StorageManagerImpl.java
index 3b29b33..c27a457 100755
--- a/server/src/com/cloud/storage/StorageManagerImpl.java
+++ b/server/src/com/cloud/storage/StorageManagerImpl.java
@@ -618,7 +618,7 @@ public class StorageManagerImpl extends ManagerBase implements StorageManager, C
             } else {
                 throw new InvalidParameterValueException("Missing parameter hypervisor. Hypervisor type is required to create zone wide primary storage.");
             }
-            if (hypervisorType != HypervisorType.KVM && hypervisorType != HypervisorType.VMware && hypervisorType != HypervisorType.Any) {
+            if (hypervisorType != HypervisorType.KVM && hypervisorType != HypervisorType.VMware && hypervisorType != HypervisorType.Hyperv && hypervisorType != HypervisorType.Any) {
                 throw new InvalidParameterValueException("zone wide storage pool is not supported for hypervisor type " + hypervisor);
             }
         }

http://git-wip-us.apache.org/repos/asf/cloudstack/blob/e3e45262/ui/scripts/system.js
----------------------------------------------------------------------
diff --git a/ui/scripts/system.js b/ui/scripts/system.js
index cdd02b2..ab5cbe9 100644
--- a/ui/scripts/system.js
+++ b/ui/scripts/system.js
@@ -15131,7 +15131,11 @@
                                                 id: 'VMware',
                                                 description: _l('VMware')
                                             });
-                                            
+                                            items.push({
+                                                id: 'Hyperv',
+                                                description: _l('Hyperv')
+                                            });
+
                                             args.response.success({
                                                 data: items
                                             });

http://git-wip-us.apache.org/repos/asf/cloudstack/blob/e3e45262/ui/scripts/zoneWizard.js
----------------------------------------------------------------------
diff --git a/ui/scripts/zoneWizard.js b/ui/scripts/zoneWizard.js
index 988e0f9..ab01c40 100755
--- a/ui/scripts/zoneWizard.js
+++ b/ui/scripts/zoneWizard.js
@@ -1429,8 +1429,8 @@
                                 return;
                             }
 
-                            //zone-wide-primary-storage is supported only for KVM and VMWare
-                            if (selectedHypervisorObj.hypervisortype == "KVM" || selectedHypervisorObj.hypervisortype == "VMware") {
+                            //zone-wide-primary-storage is supported only for KVM and VMWare and Hyperv
+                            if (selectedHypervisorObj.hypervisortype == "KVM" || selectedHypervisorObj.hypervisortype == "VMware" || selectedHypervisorObj.hypervisortype == "Hyperv") {
                                 var scope = [];
                                 scope.push({
                                     id: 'zone',